<?php

/**
 * This file contains package_quiqqer_payment-stripe_ajax_confirmSubscription
 */

use QUI\ERP\Order\Handler;
use QUI\Utils\Security\Orthos;
use QUI\ERP\Payments\Stripe\StripeException;
use QUI\ERP\Payments\Stripe\PaymentMethods\Recurring\Subscriptions;
use QUI\ERP\Payments\Stripe\AbstractBasePayment;
use Stripe\Exception\CardException;
use QUI\ERP\Payments\Stripe\PaymentMethods\Recurring\AbstractBaseRecurringPayment;

/**
 * Confirm a Stripe Subscription
 *
 * @param int $basketId - Basket ID
 * @return array - Subscription confirmation data
 */
QUI::$Ajax->registerFunction(
    'package_quiqqer_payment-stripe_ajax_confirmSubscription',
    function ($orderHash) {
        try {
            $orderHash = Orthos::clear($orderHash);
            $Order = Handler::getInstance()->getOrderByHash($orderHash);
            $paymentType = $Order->getPayment()->getPaymentType();

            if (!($paymentType instanceof AbstractBaseRecurringPayment)) {
                throw new StripeException("Cannot create Stripe subscription. Wrong order payment type.", 0, [
                    'orderUuid' => $Order->getUUID(),
                    'paymentTypeActual' => $paymentType::class
                ]);
            }

            return Subscriptions::confirmSubscription(
                $Order->getPaymentDataEntry(AbstractBasePayment::ATTR_STRIPE_SUBSCRIPTION_ID),
                $paymentType
            );
        } catch (Exception $Exception) {
            if ($Exception instanceof CardException) {
                QUI\System\Log::writeDebugException($Exception);
            } else {
                QUI\System\Log::writeException($Exception);
            }

            throw new StripeException([
                'quiqqer/payment-stripe',
                'exception.ajax.createPaymentIntent.general_error'
            ]);
        }
    },
    ['orderHash']
);
