<?php

namespace QUI\ERP\Payments\Stripe\PaymentMethods;

use QUI;
use QUI\ERP\Accounting\Payments\Payments;
use QUI\ERP\Order\AbstractOrder;
use QUI\ERP\Order\OrderInterface;
use QUI\ERP\Payments\Stripe\AbstractBasePayment;
use QUI\ERP\Payments\Stripe\Utils;
use Stripe\Exception\ApiErrorException;
use Stripe\PaymentIntent as StripePaymentIntent;
use Browser;
use QUI\ERP\Accounting\Payments\Exceptions\PaymentCanNotBeUsed as PaymentCanNotBeUsedException;

/**
 * Class BrowserPay
 *
 * Stripe payment via Browser (includes GooglePay, Apple Pay, Microsoft Pay, Browser Payment Request API)
 */
abstract class AbstractBrowserPay extends AbstractBasePayment
{
    /**
     * Return the payment icon (the URL path)
     * Can be overwritten
     *
     * @return string
     */
    public function getIcon(): string
    {
        // @todo
        return Payments::getInstance()->getHost() .
            URL_OPT_DIR .
            'quiqqer/payment-stripe/bin/images/Payment.png';
    }

    /**
     * Get type of Browser this BrowserPay works with
     *
     * @return string[]
     */
    abstract public function getBrowserTypes(): array;

    /**
     * Get type string of Stripe PaymentMethod
     *
     * @return string
     */
    public function getPaymentMethodType(): string
    {
        return 'browser_pay';
    }

    /**
     * Return attributes for creating a PaymentIntent
     *
     * @param AbstractOrder $Order
     * @param string $paymentMethodId - Stripe PaymentMethod ID
     * @return StripePaymentIntent
     *
     * @throws ApiErrorException
     * @throws QUI\Exception
     */
    protected function createPaymentIntentForOrder(AbstractOrder $Order, string $paymentMethodId): StripePaymentIntent
    {
        return StripePaymentIntent::create([
            'payment_method' => $paymentMethodId,
            'amount' => Utils::getCentAmount($Order),
            'currency' => mb_strtolower($Order->getCurrency()->getCode()),
//            'confirmation_method' => 'manual',
            'confirm' => true,
            'description' => Utils::getPaymentDescriptionForOrder($Order),
            'automatic_payment_methods' => [
                'enabled' => true,
                'allow_redirects' => 'never'
            ]
        ]);
    }

    public function canBeUsedInOrder(OrderInterface $order): bool
    {
        $B = new Browser();

        if (!$B->isMobile()) {
            return false;
        }

        if (!in_array($B->getBrowser(), $this->getBrowserTypes())) {
            return false;
        }

        return true;
    }
}
