<?php

namespace QUI\ERP\Payments\Stripe\PaymentMethods\Recurring;

use Browser;
use QUI\ERP\Order\OrderInterface;
use Stripe\PaymentIntent;
use Stripe\PaymentIntent as StripePaymentIntent;
use Stripe\Subscription;
use Stripe\Subscription as StripeSubscription;

use function in_array;

/**
 * Class AbstractRecurringBrowserPay
 *
 * Stripe payment via Browser (includes GooglePay, Apple Pay, Microsoft Pay, Browser Payment Request API)
 */
abstract class AbstractRecurringBrowserPay extends AbstractBaseRecurringPayment
{
    /**
     * Get type of Browser this BrowserPay works with
     *
     * @return string[]
     */
    abstract public function getBrowserTypes(): array;

    /**
     * Get type string of Stripe PaymentMethod
     *
     * @return string
     */
    public function getPaymentMethodType(): string
    {
        return 'browser_pay';
    }

    public function canBeUsedInOrder(OrderInterface $order): bool
    {
        $B = new Browser();

        if (!$B->isMobile()) {
            return false;
        }

        if (!in_array($B->getBrowser(), $this->getBrowserTypes())) {
            return false;
        }

        return true;
    }
}
